---
jupyter:
  kernelspec:
    display_name: Apache Toree - Scala
    language: scala
    name: apache_toree_scala
---

```{scala}
// This is just a simple scala notebook

object SampleObject {
    def calculation(x: Int, y: Int): Int = x + y
}

val result = SampleObject.calculation(1, 2)
```

```{scala}
println(result * 10)
```
